@@ -3,7 +3,7 @@ use strictures;
 use Exporter 'import';
 use Acme::MITHALDU::XSGrabBag::Inline ();
 
-our $VERSION = '1.150590'; # VERSION
+our $VERSION = '1.150720'; # VERSION
 
 # ABSTRACT: a bunch of XS math functions i'm not sure where to shove yet
 
@@ -20,9 +20,20 @@ our $VERSION = '1.150590'; # VERSION
 # not imply endorsement by the author.
 #
 
-our @EXPORT_OK = qw( mix deg2rad );
+our @EXPORT_OK = qw(
+  mix
+  deg2rad
+  rad2deg
+  dot2_product
+);
 
-Acme::MITHALDU::XSGrabBag::Inline->import( C => join "\n", _mix(), _deg2rad() );
+Acme::MITHALDU::XSGrabBag::Inline->import(
+    C => join "\n",
+    _mix(),
+    _deg2rad(),
+    _rad2deg(),
+    _dot2_product(),
+);
 
 
 sub _mix {
@@ -51,6 +62,27 @@ float deg2rad(float degrees) {
 ...
 }
 
+
+sub _rad2deg {
+    <<'...';
+float rad2deg(float radians) {
+    return 57.2957795786 * radians;
+}
+...
+}
+
+
+sub _dot2_product {
+    <<'...';
+int dot2_product( int xa, int ya, int xb, int yb ) {
+    int sum = 0;
+    sum += xa * xb;
+    sum += ya * yb;
+    return sum;
+}
+...
+}
+
 1;
 
 __END__
@@ -63,7 +95,7 @@ Acme::MITHALDU::XSGrabBag - a bunch of XS math functions i'm not sure where to s
 
 =head1 VERSION
 
-version 1.150590
+version 1.150720
 
 =head1 DESCRIPTION
 
@@ -84,6 +116,14 @@ L<Bob Jenkins|http://web.archive.org/web/20071224045401/http://www.burtleburtle.
 
 32 bit degree to radian conversion, dirty, but fast.
 
+=head2 my $rad = rad2deg( $deg )
+
+32 bit radian to degree conversion, dirty, but fast.
+
+=head2 my $dot = dot2_product( $xa, $ya, $xb, $yb )
+
+Simple dot product calculation for 2d vectors.
+
 =for :stopwords cpan testmatrix url annocpan anno bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
 
 =head1 SUPPORT
